==> zookeeper_3.8.0.orig.tar.gz: apache-zookeeper-3.8.0/zookeeper-server/src/main/java/org/apache/zookeeper/cli/CliCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zookeeper.cli;

import java.io.PrintStream;
import java.util.Map;
import org.apache.zookeeper.ZooKeeper;

/**
 * base class for all CLI commands
 */
public abstract class CliCommand {

    protected ZooKeeper zk;
    protected PrintStream out;
    protected PrintStream err;
    private String cmdStr;
    private String optionStr;

    /**
     * a CLI command with command string and options.
     * Using System.out and System.err for printing
     * @param cmdStr the string used to call this command
     * @param optionStr the string used to call this command
     */
    public CliCommand(String cmdStr, String optionStr) {
        this.out = System.out;
        this.err = System.err;
        this.cmdStr = cmdStr;
        this.optionStr = optionStr;
    }

    /**
     * Set out printStream (usable for testing)
     * @param out
     */
    public void setOut(PrintStream out) {
        this.out = out;
    }

    /**
     * Set err printStream (usable for testing)
     * @param err
     */
    public void setErr(PrintStream err) {
        this.err = err;
    }

    /**
     * set the zookeeper instance
     * @param zk the ZooKeeper instance.
     */
    public void setZk(ZooKeeper zk) {
        this.zk = zk;
    }

    /**
     * get the string used to call this command
     */
    public String getCmdStr() {
        return cmdStr;
    }

    /**
     * get the option string
     */
    public String getOptionStr() {
        return optionStr;
    }

    /**
     * get a usage string, contains the command and the options
     */
    public String getUsageStr() {
        return cmdStr + " " + optionStr;
    }

    /**
     * add this command to a map. Use the command string as key.
     * @param cmdMap
     */
    public void addToMap(Map<String, CliCommand> cmdMap) {
        cmdMap.put(cmdStr, this);
    }

    /**
     * parse the command arguments
     * @param cmdArgs
     * @return this CliCommand
     * @throws CliParseException
     */
    public abstract CliCommand parse(String[] cmdArgs) throws CliParseException;

    /**
     *
     * @return true if command has watch option, false otherwise
     * @throws CliException
     */
    public abstract boolean exec() throws CliException;

}

==> zookeeper_3.9.3.orig.tar.gz: apache-zookeeper-3.9.3/zookeeper-server/src/main/java/org/apache/zookeeper/cli/CliCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zookeeper.cli;

import java.io.PrintStream;
import java.util.Map;
import javax.annotation.Nullable;
import org.apache.commons.cli.Options;
import org.apache.zookeeper.ZooKeeper;

/**
 * base class for all CLI commands
 */
public abstract class CliCommand {

    protected ZooKeeper zk;
    protected PrintStream out;
    protected PrintStream err;
    private String cmdStr;
    private String optionStr;
    @Nullable
    private Options options;

    /**
     * a CLI command with command string and options.
     * Using System.out and System.err for printing
     * @param cmdStr the string used to call this command
     * @param optionStr the string used to call this command
     */
    public CliCommand(String cmdStr, String optionStr) {
        this(cmdStr, optionStr, null);
    }

    /**
     * a CLI command with command string and options.
     * Using System.out and System.err for printing
     * @param cmdStr the string used to call this command
     * @param optionStr the string used to call this command
     * @param options the command options
     */
    public CliCommand(String cmdStr, String optionStr, Options options) {
        this.out = System.out;
        this.err = System.err;
        this.cmdStr = cmdStr;
        this.optionStr = optionStr;
        this.options = options;
    }

    /**
     * Set out printStream (usable for testing)
     * @param out
     */
    public void setOut(PrintStream out) {
        this.out = out;
    }

    /**
     * Set err printStream (usable for testing)
     * @param err
     */
    public void setErr(PrintStream err) {
        this.err = err;
    }

    /**
     * set the zookeeper instance
     * @param zk the ZooKeeper instance.
     */
    public void setZk(ZooKeeper zk) {
        this.zk = zk;
    }

    /**
     * get the string used to call this command
     */
    public String getCmdStr() {
        return cmdStr;
    }

    /**
     * get the option string
     */
    public String getOptionStr() {
        return optionStr;
    }

    /**
     * get a usage string, contains the command and the options
     */
    public String getUsageStr() {
        return CommandUsageHelper.getUsage(cmdStr + " " + optionStr, options);
    }

    /**
     * add this command to a map. Use the command string as key.
     * @param cmdMap
     */
    public void addToMap(Map<String, CliCommand> cmdMap) {
        cmdMap.put(cmdStr, this);
    }

    /**
     * parse the command arguments
     * @param cmdArgs
     * @return this CliCommand
     * @throws CliParseException
     */
    public abstract CliCommand parse(String[] cmdArgs) throws CliParseException;

    /**
     *
     * @return true if command has watch option, false otherwise
     * @throws CliException
     */
    public abstract boolean exec() throws CliException;

}
